==> Unciv-4.5.9.tar.gz: Unciv-4.5.9/core/src/com/unciv/models/ruleset/Quest.kt <==
package com.unciv.models.ruleset

import com.unciv.models.stats.INamed

enum class QuestName(val value: String) {
    Route("Route"),
    ClearBarbarianCamp("Clear Barbarian Camp"),
    ConstructWonder("Construct Wonder"),
    ConnectResource("Connect Resource"),
    GreatPerson("Acquire Great Person"),
    ConquerCityState("Conquer City State"),
    FindPlayer("Find Player"),
    FindNaturalWonder("Find Natural Wonder"),
    GiveGold("Give Gold"),
    PledgeToProtect("Pledge to Protect"),
    ContestCulture("Contest Culture"),
    ContestFaith("Contest Faith"),
    ContestTech("Contest Technologies"),
    Invest("Invest"),
    BullyCityState("Bully City State"),
    DenounceCiv("Denounce Civilization"),
    SpreadReligion("Spread Religion"),
    None("")
}

enum class QuestType {
    Individual,
    Global
}

/** [Quest] class holds all functionality relative to a quest */
class Quest : INamed {

    /** Unique identifier name of the quest, it is also shown */
    override var name: String = ""

    /** Description of the quest shown to players */
    var description: String = ""

    /** [QuestType]: it is either Individual or Global */
    var type: QuestType = QuestType.Individual

    /** Influence reward gained on quest completion */
    var influence: Float = 40f

    /** Maximum number of turns to complete the quest, 0 if there's no turn limit */
    var duration: Int = 0

    /** Minimum number of [CivInfo] needed to start the quest. It is meaningful only for [QuestType.Global]
     *  quests [type]. */
    var minimumCivs: Int = 1

    /** Certain city states are more likely to give certain quests
     * This is based on both personality and city-state type
     * Both are mapped here as 'how much to multiply the weight of this quest for this kind of city-state' */
    var weightForCityStateType = HashMap<String, Float>()

    /** Checks if [this] is a Global quest */
    fun isGlobal(): Boolean = type == QuestType.Global
    fun isIndividual(): Boolean = !isGlobal()
}

==> Unciv-4.7.19.tar.gz: Unciv-4.7.19/core/src/com/unciv/models/ruleset/Quest.kt <==
package com.unciv.models.ruleset

import com.unciv.models.stats.INamed
import com.unciv.logic.civilization.Civilization // for Kdoc

enum class QuestName(val value: String) {
    Route("Route"),
    ClearBarbarianCamp("Clear Barbarian Camp"),
    ConstructWonder("Construct Wonder"),
    ConnectResource("Connect Resource"),
    GreatPerson("Acquire Great Person"),
    ConquerCityState("Conquer City State"),
    FindPlayer("Find Player"),
    FindNaturalWonder("Find Natural Wonder"),
    GiveGold("Give Gold"),
    PledgeToProtect("Pledge to Protect"),
    ContestCulture("Contest Culture"),
    ContestFaith("Contest Faith"),
    ContestTech("Contest Technologies"),
    Invest("Invest"),
    BullyCityState("Bully City State"),
    DenounceCiv("Denounce Civilization"),
    SpreadReligion("Spread Religion"),
    None("")
}

enum class QuestType {
    Individual,
    Global
}

/** [Quest] class holds all functionality relative to a quest */
// Notes: This is **not** `IsPartOfGameInfoSerialization`, only Ruleset.
// Saves contain [QuestManager]s instead, which contain lists of [AssignedQuest] instances.
// These are matched to this Quest **by name**.
// Note [name] must match one of the [QuestName] _values_ above for the Quest to have any functionality.
class Quest : INamed {

    /** Unique identifier name of the quest, it is also shown */
    override var name: String = ""

    /** Description of the quest shown to players */
    var description: String = ""

    /** [QuestType]: it is either Individual or Global */
    var type: QuestType = QuestType.Individual

    /** Influence reward gained on quest completion */
    var influence: Float = 40f

    /** Maximum number of turns to complete the quest, 0 if there's no turn limit */
    var duration: Int = 0

    /** Minimum number of [Civilization]s needed to start the quest. It is meaningful only for [QuestType.Global]
     *  quests [type]. */
    var minimumCivs: Int = 1

    /** Certain city states are more likely to give certain quests
     * This is based on both personality and city-state type
     * Both are mapped here as 'how much to multiply the weight of this quest for this kind of city-state' */
    var weightForCityStateType = HashMap<String, Float>()

    /** Checks if `this` is a Global quest */
    fun isGlobal(): Boolean = type == QuestType.Global
    fun isIndividual(): Boolean = !isGlobal()
}
